# coding: utf-8

# flake8: noqa
"""
    Tinq AI V2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Contact: boulama@tinq.ai
    A Python wrapper for the Tinq.ai API - an easy-to-use text analysis and natural language processing toolkit.
    Generated by OpenAPI Generator

"""  # noqa: E501


# import models into model package



# flake8: noqa

# import apis into api package
from tinq.api.assistant import Assistant
from tinq.api.classifiers import Classifiers
from tinq.api.plagiarism_checker import PlagiarismChecker
from tinq.api.projects import Projects
from tinq.api.scraper import Scraper
from tinq.api.tools import Tools
from tinq.api.workflows import Workflows




# coding: utf-8

# flake8: noqa

"""
    Tinq AI V2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Contact: boulama@tinq.ai
    A Python wrapper for the Tinq.ai API - an easy-to-use text analysis and natural language processing toolkit.
    Generated by OpenAPI Generator

"""  # noqa: E501


__version__ = "1.26.0"

# import apis into sdk package
from tinq.api.assistant import Assistant
from tinq.api.classifiers import Classifiers
from tinq.api.plagiarism_checker import PlagiarismChecker
from tinq.api.projects import Projects
from tinq.api.scraper import Scraper
from tinq.api.tools import Tools
from tinq.api.workflows import Workflows

# import ApiClient
from tinq.api_response import ApiResponse
from tinq.api_client import ApiClient
from tinq.configuration import Configuration
from tinq.exceptions import OpenApiException
from tinq.exceptions import ApiTypeError
from tinq.exceptions import ApiValueError
from tinq.exceptions import ApiKeyError
from tinq.exceptions import ApiAttributeError
from tinq.exceptions import ApiException

# import models into sdk package



# coding: utf-8

"""
    Tinq AI V2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Contact: boulama@tinq.ai
    A Python wrapper for the Tinq.ai API - an easy-to-use text analysis and natural language processing toolkit.
    Generated by OpenAPI Generator

"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "tinq"
VERSION = "1.26.0"
PYTHON_REQUIRES = ">= 3.8"
REQUIRES = [
    "urllib3 >= 1.25.3, < 3.0.0",
    "python-dateutil >= 2.8.2",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="Tinq AI V2",
    author="Boulama",
    author_email="boulama@tinq.ai",
    url="https://pypi.org/project/tinq/appDescription&#x3D;Official Tinq.ai python SDKprojectName&#x3D;tinq",
    keywords=["OpenAPI", "OpenAPI-Generator", "Tinq AI V2"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description_content_type='text/markdown',
    long_description="""\
    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
    """,  # noqa: E501
    package_data={"tinq": ["py.typed"]},
)
